@@ -1,23 +1,23 @@
+from collections.abc import Sequence
 from functools import update_wrapper
-from typing import (
+from typing import (  # noqa: UP035
     TYPE_CHECKING,
     AbstractSet,
     Any,
     Callable,
     Optional,
-    Sequence,
     Union,
     cast,
     overload,
 )
 
 import dagster._check as check
+from dagster._annotations import public
+from dagster._core.decorator_utils import get_function_params, validate_expected_params
+from dagster._core.definitions.events import HookExecutionResult
+from dagster._core.definitions.hook_definition import HookDefinition
 from dagster._core.errors import DagsterInvalidDefinitionError
 
-from ...decorator_utils import get_function_params, validate_expected_params
-from ..events import HookExecutionResult
-from ..hook_definition import HookDefinition
-
 if TYPE_CHECKING:
     from dagster._core.events import DagsterEvent
     from dagster._core.execution.context.hook import HookContext
@@ -28,12 +28,10 @@ def _validate_hook_fn_params(fn, expected_positionals):
     missing_positional = validate_expected_params(params, expected_positionals)
     if missing_positional:
         raise DagsterInvalidDefinitionError(
-            "'{hook_name}' decorated function does not have required positional "
-            "parameter '{missing_param}'. Hook functions should only have keyword arguments "
+            f"'{fn.__name__}' decorated function does not have required positional "
+            f"parameter '{missing_positional}'. Hook functions should only have keyword arguments "
             "that match input names and a first positional parameter named 'context' and "
-            "a second positional parameter named 'event_list'.".format(
-                hook_name=fn.__name__, missing_param=missing_positional
-            )
+            "a second positional parameter named 'event_list'."
         )
 
 
@@ -66,13 +64,13 @@ class _Hook:
             required_resource_keys=self.required_resource_keys,
             decorated_fn=self.decorated_fn or fn,
         )
-        update_wrapper(cast(Callable[..., Any], hook_def), fn)
+        update_wrapper(cast("Callable[..., Any]", hook_def), fn)
         return hook_def
 
 
 @overload
 def event_list_hook(
-    hook_fn: Callable,
+    hook_fn: Callable[..., Any],
 ) -> HookDefinition:
     pass
 
@@ -102,9 +100,9 @@ def event_list_hook(
     The user-defined hook function requires two parameters:
     - A `context` object is passed as the first parameter. The context is an instance of
         :py:class:`context <HookContext>`, and provides access to system
-        information, such as loggers (context.log), resources (context.resources), the solid
-        (context.solid) and its execution step (context.step) which triggers this hook.
-    - An `event_list` object is passed as the second paramter. It provides the full event list of the
+        information, such as loggers (context.log), resources (context.resources), the op
+        (context.op) and its execution step (context.step) which triggers this hook.
+    - An `event_list` object is passed as the second parameter. It provides the full event list of the
         associated execution step.
 
     Args:
@@ -119,10 +117,7 @@ def event_list_hook(
             def slack_on_materializations(context, event_list):
                 for event in event_list:
                     if event.event_type == DagsterEventType.ASSET_MATERIALIZATION:
-                        message = '{solid} has materialized an asset {key}.'.format(
-                            solid=context.solid.name,
-                            key=event.asset_key
-                        )
+                        message = f'{context.op_name} has materialized an asset {event.asset_key}.'
                         # send a slack message every time a materialization event occurs
                         context.resources.slack.send_message(message)
 
@@ -143,8 +138,7 @@ SuccessOrFailureHookFn = Callable[["HookContext"], Any]
 
 
 @overload
-def success_hook(hook_fn: SuccessOrFailureHookFn) -> HookDefinition:
-    ...
+def success_hook(hook_fn: SuccessOrFailureHookFn) -> HookDefinition: ...
 
 
 @overload
@@ -152,10 +146,10 @@ def success_hook(
     *,
     name: Optional[str] = ...,
     required_resource_keys: Optional[AbstractSet[str]] = ...,
-) -> Callable[[SuccessOrFailureHookFn], HookDefinition]:
-    ...
+) -> Callable[[SuccessOrFailureHookFn], HookDefinition]: ...
 
 
+@public
 def success_hook(
     hook_fn: Optional[SuccessOrFailureHookFn] = None,
     *,
@@ -218,18 +212,17 @@ def success_hook(
 
 
 @overload
-def failure_hook(name: SuccessOrFailureHookFn) -> HookDefinition:
-    ...
+def failure_hook(name: SuccessOrFailureHookFn) -> HookDefinition: ...
 
 
 @overload
 def failure_hook(
     name: Optional[str] = ...,
     required_resource_keys: Optional[AbstractSet[str]] = ...,
-) -> Callable[[SuccessOrFailureHookFn], HookDefinition]:
-    ...
+) -> Callable[[SuccessOrFailureHookFn], HookDefinition]: ...
 
 
+@public
 def failure_hook(
     name: Optional[Union[SuccessOrFailureHookFn, str]] = None,
     required_resource_keys: Optional[AbstractSet[str]] = None,
