@@ -6,8 +6,9 @@ for that.
 
 from abc import ABC, abstractmethod
 from collections.abc import Sequence
-from typing import TYPE_CHECKING, Optional
+from typing import TYPE_CHECKING, Annotated, Optional, Union
 
+from dagster_shared.record import ImportFrom
 from typing_extensions import Self
 
 from dagster import _check as check
@@ -25,6 +26,7 @@ if TYPE_CHECKING:
         StaticPartitionsDefinition,
         TimeWindowPartitionsDefinition,
     )
+    from dagster._core.definitions.timestamp import TimestampWithTimezone
 
 
 class PartitionsSnap(ABC):
@@ -64,6 +66,16 @@ class TimeWindowPartitionsSnap(PartitionsSnap):
     end_offset: int
     end: Optional[float] = None
     cron_schedule: Optional[str] = None
+    exclusions: Optional[
+        Sequence[
+            Union[
+                str,
+                Annotated[
+                    "TimestampWithTimezone", ImportFrom("dagster._core.definitions.timestamp")
+                ],
+            ]
+        ]
+    ] = None
     # superseded by cron_schedule, but kept around for backcompat
     schedule_type: Optional[ScheduleType] = None
     # superseded by cron_schedule, but kept around for backcompat
@@ -85,6 +97,7 @@ class TimeWindowPartitionsSnap(PartitionsSnap):
             timezone=partitions_def.timezone,
             fmt=partitions_def.fmt,
             end_offset=partitions_def.end_offset,
+            exclusions=partitions_def.exclusions if partitions_def.exclusions else None,
         )
 
     def get_partitions_definition(self):
@@ -98,6 +111,7 @@ class TimeWindowPartitionsSnap(PartitionsSnap):
                 fmt=self.fmt,
                 end_offset=self.end_offset,
                 end=(datetime_from_timestamp(self.end, tz=self.timezone) if self.end else None),  # pyright: ignore[reportArgumentType]
+                exclusions=self.exclusions if self.exclusions else None,
             )
         else:
             # backcompat case
@@ -111,6 +125,7 @@ class TimeWindowPartitionsSnap(PartitionsSnap):
                 minute_offset=self.minute_offset,
                 hour_offset=self.hour_offset,
                 day_offset=self.day_offset,
+                exclusions=self.exclusions if self.exclusions else None,
             )
 
 
