@@ -1,81 +1,51 @@
+from collections.abc import Iterable, Iterator, Mapping, Sequence
 from datetime import datetime
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    Iterable,
-    Iterator,
-    List,
-    Mapping,
-    Optional,
-    Sequence,
-    Union,
-)
+from typing import TYPE_CHECKING, Any, Optional, Union
 
 import dagster._check as check
-from dagster._annotations import public
-from dagster._core.definitions.events import AssetKey, AssetObservation
-from dagster._core.definitions.metadata import (
-    ArbitraryMetadataMapping,
-    MetadataValue,
-)
-from dagster._core.definitions.partition import PartitionsSubset
-from dagster._core.definitions.partition_key_range import PartitionKeyRange
-from dagster._core.definitions.time_window_partitions import TimeWindow, TimeWindowPartitionsSubset
+from dagster._annotations import deprecated, deprecated_param, public
+from dagster._core.definitions.events import AssetKey, AssetObservation, CoercibleToAssetKey
+from dagster._core.definitions.metadata import ArbitraryMetadataMapping, MetadataValue
+from dagster._core.definitions.partitions.context import partition_loading_context
+from dagster._core.definitions.partitions.partition_key_range import PartitionKeyRange
+from dagster._core.definitions.partitions.subset import PartitionsSubset
+from dagster._core.definitions.partitions.utils import TimeWindow
 from dagster._core.errors import DagsterInvariantViolationError
-from dagster._core.instance import DagsterInstance, DynamicPartitionsStore
+from dagster._core.instance import DagsterInstance
+from dagster._utils.warnings import normalize_renamed_param
 
 if TYPE_CHECKING:
     from dagster._core.definitions import PartitionsDefinition
     from dagster._core.definitions.op_definition import OpDefinition
     from dagster._core.definitions.resource_definition import Resources
     from dagster._core.events import DagsterEvent
+    from dagster._core.execution.context.output import OutputContext
     from dagster._core.execution.context.system import StepExecutionContext
     from dagster._core.log_manager import DagsterLogManager
     from dagster._core.types.dagster_type import DagsterType
 
-    from .output import OutputContext
-
 
+@deprecated_param(
+    param="metadata",
+    breaking_version="2.0",
+    additional_warn_text="Use `definition_metadata` instead.",
+)
+@public
 class InputContext:
-    """The ``context`` object available to the load_input method of :py:class:`RootInputManager`.
+    """The ``context`` object available to the load_input method of :py:class:`InputManager`.
 
     Users should not instantiate this object directly. In order to construct
     an `InputContext` for testing an IO Manager's `load_input` method, use
     :py:func:`dagster.build_input_context`.
 
-    Attributes:
-        name (Optional[str]): The name of the input that we're loading.
-        config (Optional[Any]): The config attached to the input that we're loading.
-        metadata (Optional[Dict[str, Any]]): A dict of metadata that is assigned to the
-            InputDefinition that we're loading for.
-            This property only contains metadata passed in explicitly with :py:class:`AssetIn`
-            or :py:class:`In`. To access metadata of an upstream asset or operation definition,
-            use the metadata in :py:attr:`.InputContext.upstream_output`.
-        upstream_output (Optional[OutputContext]): Info about the output that produced the object
-            we're loading.
-        dagster_type (Optional[DagsterType]): The type of this input.
-            Dagster types do not propagate from an upstream output to downstream inputs,
-            and this property only captures type information for the input that is either
-            passed in explicitly with :py:class:`AssetIn` or :py:class:`In`, or can be
-            infered from type hints. For an asset input, the Dagster type from the upstream
-            asset definition is ignored.
-        log (Optional[DagsterLogManager]): The log manager to use for this input.
-        resource_config (Optional[Dict[str, Any]]): The config associated with the resource that
-            initializes the RootInputManager.
-        resources (Optional[Resources]): The resources required by the resource that initializes the
-            input manager. If using the :py:func:`@root_input_manager` decorator, these resources
-            correspond to those requested with the `required_resource_keys` parameter.
-        op_def (Optional[OpDefinition]): The definition of the op that's loading the input.
-
     Example:
-    .. code-block:: python
+        .. code-block:: python
 
-        from dagster import IOManager, InputContext
-
-        class MyIOManager(IOManager):
-            def load_input(self, context: InputContext):
-                ...
+            from dagster import IOManager, InputContext
 
+            class MyIOManager(IOManager):
+                def load_input(self, context: InputContext):
+                    ...
     """
 
     def __init__(
@@ -85,7 +55,7 @@ class InputContext:
         job_name: Optional[str] = None,
         op_def: Optional["OpDefinition"] = None,
         config: Optional[Any] = None,
-        metadata: Optional[ArbitraryMetadataMapping] = None,
+        definition_metadata: Optional[ArbitraryMetadataMapping] = None,
         upstream_output: Optional["OutputContext"] = None,
         dagster_type: Optional["DagsterType"] = None,
         log_manager: Optional["DagsterLogManager"] = None,
@@ -97,6 +67,8 @@ class InputContext:
         asset_partitions_subset: Optional[PartitionsSubset] = None,
         asset_partitions_def: Optional["PartitionsDefinition"] = None,
         instance: Optional[DagsterInstance] = None,
+        # deprecated
+        metadata: Optional[ArbitraryMetadataMapping] = None,
     ):
         from dagster._core.definitions.resource_definition import IContainsGenerator, Resources
         from dagster._core.execution.build_resources import build_resources
@@ -105,7 +77,13 @@ class InputContext:
         self._job_name = job_name
         self._op_def = op_def
         self._config = config
-        self._metadata = metadata or {}
+        self._definition_metadata = (
+            normalize_renamed_param(
+                definition_metadata, "definition_metadata", metadata, "metadata"
+            )
+            or {}
+        )
+        self._user_generated_metadata = {}
         self._upstream_output = upstream_output
         self._dagster_type = dagster_type
         self._log = log_manager
@@ -131,8 +109,8 @@ class InputContext:
             self._resources_contain_cm = isinstance(self._resources, IContainsGenerator)
             self._cm_scope_entered = False
 
-        self._events: List["DagsterEvent"] = []
-        self._observations: List[AssetObservation] = []
+        self._events: list[DagsterEvent] = []
+        self._observations: list[AssetObservation] = []
         self._instance = instance
 
     def __enter__(self):
@@ -168,6 +146,7 @@ class InputContext:
     @public
     @property
     def name(self) -> str:
+        """The name of the input that we're loading."""
         if self._name is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access name, "
@@ -185,13 +164,10 @@ class InputContext:
             )
         return self._job_name
 
-    @property
-    def pipeline_name(self) -> str:
-        return self.job_name
-
     @public
     @property
     def op_def(self) -> "OpDefinition":
+        """The definition of the op that's loading the input."""
         if self._op_def is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access op_def, "
@@ -203,21 +179,42 @@ class InputContext:
     @public
     @property
     def config(self) -> Any:
+        """The config attached to the input that we're loading."""
         return self._config
 
+    @deprecated(breaking_version="2.0.0", additional_warn_text="Use definition_metadata instead")
     @public
     @property
     def metadata(self) -> Optional[ArbitraryMetadataMapping]:
-        return self._metadata
+        """Deprecated: Use definitiion_metadata instead."""
+        return self._definition_metadata
+
+    @public
+    @property
+    def definition_metadata(self) -> ArbitraryMetadataMapping:
+        """A dict of metadata that is assigned to the InputDefinition that we're loading.
+        This property only contains metadata passed in explicitly with :py:class:`AssetIn`
+        or :py:class:`In`. To access metadata of an upstream asset or op definition,
+        use the definition_metadata in :py:attr:`.InputContext.upstream_output`.
+        """
+        return self._definition_metadata
 
     @public
     @property
     def upstream_output(self) -> Optional["OutputContext"]:
+        """Info about the output that produced the object we're loading."""
         return self._upstream_output
 
     @public
     @property
     def dagster_type(self) -> "DagsterType":
+        """The type of this input.
+        Dagster types do not propagate from an upstream output to downstream inputs,
+        and this property only captures type information for the input that is either
+        passed in explicitly with :py:class:`AssetIn` or :py:class:`In`, or can be
+        infered from type hints. For an asset input, the Dagster type from the upstream
+        asset definition is ignored.
+        """
         if self._dagster_type is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access dagster_type, "
@@ -229,6 +226,7 @@ class InputContext:
     @public
     @property
     def log(self) -> "DagsterLogManager":
+        """The log manager to use for this input."""
         if self._log is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access log, "
@@ -240,11 +238,16 @@ class InputContext:
     @public
     @property
     def resource_config(self) -> Optional[Mapping[str, Any]]:
+        """The config associated with the resource that initializes the InputManager."""
         return self._resource_config
 
     @public
     @property
     def resources(self) -> Any:
+        """The resources required by the resource that initializes the
+        input manager. If using the :py:func:`@input_manager` decorator, these resources
+        correspond to those requested with the `required_resource_keys` parameter.
+        """
         if self._resources is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access resources, "
@@ -262,11 +265,15 @@ class InputContext:
     @public
     @property
     def has_asset_key(self) -> bool:
+        """Returns True if an asset is being loaded as input, otherwise returns False. A return value of False
+        indicates that an output from an op is being loaded as the input.
+        """
         return self._asset_key is not None
 
     @public
     @property
     def asset_key(self) -> AssetKey:
+        """The ``AssetKey`` of the asset that is being loaded as an input."""
         if self._asset_key is None:
             raise DagsterInvariantViolationError(
                 "Attempting to access asset_key, but no asset is associated with this input"
@@ -325,6 +332,7 @@ class InputContext:
     @public
     @property
     def has_asset_partitions(self) -> bool:
+        """Returns True if the asset being loaded as input is partitioned."""
         return self._asset_partitions_subset is not None
 
     @public
@@ -363,15 +371,11 @@ class InputContext:
                 "Tried to access asset_partition_key_range, but the asset is not partitioned.",
             )
 
-        partition_key_ranges = subset.get_partition_key_ranges(
-            dynamic_partitions_store=self.instance
-        )
+        partition_key_ranges = subset.get_partition_key_ranges(self.asset_partitions_def)
         if len(partition_key_ranges) != 1:
             check.failed(
-                (
-                    "Tried to access asset_partition_key_range, but there are "
-                    f"({len(partition_key_ranges)}) key ranges associated with this input."
-                ),
+                "Tried to access asset_partition_key_range, but there are "
+                f"({len(partition_key_ranges)}) key ranges associated with this input.",
             )
 
         return partition_key_ranges[0]
@@ -397,7 +401,8 @@ class InputContext:
 
         Raises an error if either of the following are true:
         - The input asset has no partitioning.
-        - The input asset is not partitioned with a TimeWindowPartitionsDefinition.
+        - The input asset is not partitioned with a TimeWindowPartitionsDefinition or a
+        MultiPartitionsDefinition with one time-partitioned dimension.
         """
         subset = self._asset_partitions_subset
 
@@ -406,24 +411,7 @@ class InputContext:
                 "Tried to access asset_partitions_time_window, but the asset is not partitioned.",
             )
 
-        if not isinstance(subset, TimeWindowPartitionsSubset):
-            check.failed(
-                (
-                    "Tried to access asset_partitions_time_window, but the asset is not partitioned"
-                    " with time windows."
-                ),
-            )
-
-        time_windows = subset.included_time_windows
-        if len(time_windows) != 1:
-            check.failed(
-                (
-                    "Tried to access asset_partition_key_range, but there are "
-                    f"({len(time_windows)}) partitions associated with this input."
-                ),
-            )
-
-        return time_windows[0]
+        return self.step_context.asset_partitions_time_window_for_input(self.name)
 
     @public
     def get_identifier(self) -> Sequence[str]:
@@ -454,6 +442,11 @@ class InputContext:
 
     @public
     def get_asset_identifier(self) -> Sequence[str]:
+        """The sequence of strings making up the AssetKey for the asset being loaded as an input.
+        If the asset is partitioned, the identifier contains the partition key as the final element in the
+        sequence. For example, for the asset key ``AssetKey(["foo", "bar", "baz"])``, materialized with
+        partition key "2023-06-01", ``get_asset_identifier`` will return ``["foo", "bar", "baz", "2023-06-01"]``.
+        """
         if self.asset_key is not None:
             if self.has_asset_partitions:
                 return [*self.asset_key.path, self.asset_partition_key]
@@ -486,7 +479,10 @@ class InputContext:
         from dagster._core.events import DagsterEvent
 
         metadata = check.mapping_param(metadata, "metadata", key_type=str)
-        self._metadata = {**self._metadata, **normalize_metadata(metadata)}
+        self._user_generated_metadata = {
+            **self._user_generated_metadata,
+            **normalize_metadata(metadata),
+        }
         if self.has_asset_key:
             check.opt_str_param(description, "description")
 
@@ -526,27 +522,42 @@ class InputContext:
         """
         return self._observations
 
-    def consume_metadata(self) -> Mapping[str, MetadataValue]:
-        result = self._metadata
-        self._metadata = {}
+    def consume_logged_metadata(self) -> Mapping[str, MetadataValue]:
+        """Pops and yields all user-generated metadata entries that have been recorded from this context.
+
+        If consume_logged_metadata has not yet been called, this will yield all logged events since
+        the call to `load_input`. If consume_logged_metadata has been called, it will yield all
+        events since the last time consume_logged_metadata was called. Designed for internal
+        use. Users should never need to invoke this method.
+        """
+        result = self._user_generated_metadata
+        self._user_generated_metadata = {}
         return result
 
 
+@public
+@deprecated_param(
+    param="metadata",
+    breaking_version="2.0",
+    additional_warn_text="Use `definition_metadata` instead.",
+)
 def build_input_context(
     name: Optional[str] = None,
     config: Optional[Any] = None,
-    metadata: Optional[ArbitraryMetadataMapping] = None,
+    definition_metadata: Optional[ArbitraryMetadataMapping] = None,
     upstream_output: Optional["OutputContext"] = None,
     dagster_type: Optional["DagsterType"] = None,
     resource_config: Optional[Mapping[str, Any]] = None,
     resources: Optional[Mapping[str, Any]] = None,
     op_def: Optional["OpDefinition"] = None,
     step_context: Optional["StepExecutionContext"] = None,
-    asset_key: Optional["AssetKey"] = None,
+    asset_key: Optional[CoercibleToAssetKey] = None,
     partition_key: Optional[str] = None,
     asset_partition_key_range: Optional[PartitionKeyRange] = None,
     asset_partitions_def: Optional["PartitionsDefinition"] = None,
     instance: Optional[DagsterInstance] = None,
+    # deprecated
+    metadata: Optional[ArbitraryMetadataMapping] = None,
 ) -> "InputContext":
     """Builds input context from provided parameters.
 
@@ -557,7 +568,7 @@ def build_input_context(
     Args:
         name (Optional[str]): The name of the input that we're loading.
         config (Optional[Any]): The config attached to the input that we're loading.
-        metadata (Optional[Dict[str, Any]]): A dict of metadata that is assigned to the
+        definition_metadata (Optional[Dict[str, Any]]): A dict of metadata that is assigned to the
             InputDefinition that we're loading for.
         upstream_output (Optional[OutputContext]): Info about the output that produced the object
             we're loading.
@@ -568,11 +579,12 @@ def build_input_context(
         resources (Optional[Dict[str, Any]]): The resources to make available from the context.
             For a given key, you can provide either an actual instance of an object, or a resource
             definition.
-        asset_key (Optional[AssetKey]): The asset key attached to the InputDefinition.
+        asset_key (Optional[Union[AssetKey, Sequence[str], str]]): The asset key attached to the InputDefinition.
         op_def (Optional[OpDefinition]): The definition of the op that's loading the input.
         step_context (Optional[StepExecutionContext]): For internal use.
         partition_key (Optional[str]): String value representing partition key to execute with.
-        asset_partition_key_range (Optional[str]): The range of asset partition keys to load.
+        asset_partition_key_range (Optional[PartitionKeyRange]): The range of asset partition keys
+            to load.
         asset_partitions_def: Optional[PartitionsDefinition]: The PartitionsDefinition of the asset
             being loaded.
 
@@ -587,18 +599,25 @@ def build_input_context(
     from dagster._core.definitions import OpDefinition, PartitionsDefinition
     from dagster._core.execution.context.output import OutputContext
     from dagster._core.execution.context.system import StepExecutionContext
-    from dagster._core.execution.context_creation_pipeline import initialize_console_manager
+    from dagster._core.execution.context_creation_job import initialize_console_manager
     from dagster._core.types.dagster_type import DagsterType
 
     name = check.opt_str_param(name, "name")
-    metadata = check.opt_mapping_param(metadata, "metadata", key_type=str)
+    check.opt_mapping_param(definition_metadata, "definition_metadata", key_type=str)
+    check.opt_mapping_param(metadata, "metadata", key_type=str)
+    definition_metadata = normalize_renamed_param(
+        definition_metadata,
+        "definition_metadata",
+        metadata,
+        "metadata",
+    )
     upstream_output = check.opt_inst_param(upstream_output, "upstream_output", OutputContext)
     dagster_type = check.opt_inst_param(dagster_type, "dagster_type", DagsterType)
     resource_config = check.opt_mapping_param(resource_config, "resource_config", key_type=str)
     resources = check.opt_mapping_param(resources, "resources", key_type=str)
     op_def = check.opt_inst_param(op_def, "op_def", OpDefinition)
     step_context = check.opt_inst_param(step_context, "step_context", StepExecutionContext)
-    asset_key = check.opt_inst_param(asset_key, "asset_key", AssetKey)
+    asset_key = AssetKey.from_coercible(asset_key) if asset_key else None
     partition_key = check.opt_str_param(partition_key, "partition_key")
     asset_partition_key_range = check.opt_inst_param(
         asset_partition_key_range, "asset_partition_key_range", PartitionKeyRange
@@ -607,9 +626,10 @@ def build_input_context(
         asset_partitions_def, "asset_partitions_def", PartitionsDefinition
     )
     if asset_partitions_def and asset_partition_key_range:
-        asset_partitions_subset = asset_partitions_def.empty_subset().with_partition_key_range(
-            asset_partition_key_range, dynamic_partitions_store=instance
-        )
+        with partition_loading_context(dynamic_partitions_store=instance):
+            asset_partitions_subset = asset_partitions_def.empty_subset().with_partition_key_range(
+                asset_partitions_def, asset_partition_key_range
+            )
     elif asset_partition_key_range:
         asset_partitions_subset = KeyRangeNoPartitionsDefPartitionsSubset(asset_partition_key_range)
     else:
@@ -619,7 +639,7 @@ def build_input_context(
         name=name,
         job_name=None,
         config=config,
-        metadata=metadata,
+        definition_metadata=definition_metadata,
         upstream_output=upstream_output,
         dagster_type=dagster_type,
         log_manager=initialize_console_manager(None),
@@ -642,9 +662,7 @@ class KeyRangeNoPartitionsDefPartitionsSubset(PartitionsSubset):
         self._key_range = key_range
 
     def get_partition_keys_not_in_subset(
-        self,
-        current_time: Optional[datetime] = None,
-        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+        self, partitions_def: "PartitionsDefinition"
     ) -> Iterable[str]:
         raise NotImplementedError()
 
@@ -655,19 +673,15 @@ class KeyRangeNoPartitionsDefPartitionsSubset(PartitionsSubset):
             raise NotImplementedError()
 
     def get_partition_key_ranges(
-        self,
-        current_time: Optional[datetime] = None,
-        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+        self, partitions_def: "PartitionsDefinition"
     ) -> Sequence[PartitionKeyRange]:
         return [self._key_range]
 
     def with_partition_keys(self, partition_keys: Iterable[str]) -> "PartitionsSubset":
         raise NotImplementedError()
 
-    def with_partition_key_range(
-        self,
-        partition_key_range: PartitionKeyRange,
-        dynamic_partitions_store: Optional[DynamicPartitionsStore] = None,
+    def with_partition_key_range(  # pyright: ignore[reportIncompatibleMethodOverride]
+        self, partition_key_range: PartitionKeyRange
     ) -> "PartitionsSubset":
         raise NotImplementedError()
 
@@ -675,7 +689,7 @@ class KeyRangeNoPartitionsDefPartitionsSubset(PartitionsSubset):
         raise NotImplementedError()
 
     @property
-    def partitions_def(self) -> "PartitionsDefinition":
+    def partitions_def(self) -> Optional["PartitionsDefinition"]:
         raise NotImplementedError()
 
     def __len__(self) -> int:
@@ -700,6 +714,11 @@ class KeyRangeNoPartitionsDefPartitionsSubset(PartitionsSubset):
     ) -> bool:
         raise NotImplementedError()
 
+    def empty_subset(self) -> "PartitionsSubset":
+        raise NotImplementedError()
+
     @classmethod
-    def empty_subset(cls, partitions_def: "PartitionsDefinition") -> "PartitionsSubset":
+    def create_empty_subset(
+        cls, partitions_def: Optional["PartitionsDefinition"] = None
+    ) -> "PartitionsSubset":
         raise NotImplementedError()
