@@ -1,11 +1,14 @@
 from abc import ABC, abstractmethod
-from typing import AbstractSet, Callable, List, Optional, Sequence, Set, cast
+from collections.abc import Sequence
+from typing import AbstractSet, Callable, Optional, cast  # noqa: UP035
+
+from dagster_shared.error import DagsterError
 
 import dagster._check as check
-from dagster._core.definitions import JobDefinition, NodeHandle
+from dagster._core.definitions import AssetCheckEvaluation, JobDefinition, NodeHandle
 from dagster._core.definitions.events import AssetMaterialization, AssetObservation
 from dagster._core.definitions.utils import DEFAULT_OUTPUT
-from dagster._core.errors import DagsterError, DagsterInvariantViolationError
+from dagster._core.errors import DagsterInvariantViolationError
 from dagster._core.events import (
     AssetObservationData,
     DagsterEvent,
@@ -16,24 +19,21 @@ from dagster._core.events import (
 )
 from dagster._core.execution.plan.objects import StepFailureData
 from dagster._core.execution.plan.step import StepKind
-from dagster._core.storage.pipeline_run import DagsterRun
+from dagster._core.storage.dagster_run import DagsterRun
 
 
 class ExecutionResult(ABC):
     @property
     @abstractmethod
-    def job_def(self) -> JobDefinition:
-        ...
+    def job_def(self) -> JobDefinition: ...
 
     @property
     @abstractmethod
-    def dagster_run(self) -> DagsterRun:
-        ...
+    def dagster_run(self) -> DagsterRun: ...
 
     @property
     @abstractmethod
-    def all_events(self) -> Sequence[DagsterEvent]:
-        ...
+    def all_events(self) -> Sequence[DagsterEvent]: ...
 
     @property
     @abstractmethod
@@ -49,7 +49,7 @@ class ExecutionResult(ABC):
     @property
     def all_node_events(self) -> Sequence[DagsterEvent]:
         """List[DagsterEvent]: All dagster events from the execution."""
-        step_events: List[DagsterEvent] = []
+        step_events: list[DagsterEvent] = []
 
         for node_name in self.job_def.graph.node_dict.keys():
             handle = NodeHandle.from_string(node_name)
@@ -65,7 +65,7 @@ class ExecutionResult(ABC):
         def _is_event_from_node(event: DagsterEvent) -> bool:
             if not event.is_step_event:
                 return False
-            node_handle = cast(NodeHandle, event.node_handle)
+            node_handle = cast("NodeHandle", event.node_handle)
             return node_handle.is_or_descends_from(handle)
 
         return self.filter_events(_is_event_from_node)
@@ -121,8 +121,20 @@ class ExecutionResult(ABC):
 
         return self._filter_events_by_handle(NodeHandle.from_string(node_name))
 
-    def get_job_failure_event(self) -> DagsterEvent:
-        """Returns a DagsterEvent with type DagsterEventType.PIPELINE_FAILURE if it ocurred during
+    def is_node_success(self, node_str: str) -> bool:
+        return any(evt.is_step_success for evt in self.events_for_node(node_str))
+
+    def is_node_failed(self, node_str: str) -> bool:
+        return any(evt.is_step_failure for evt in self.events_for_node(node_str))
+
+    def is_node_skipped(self, node_str: str) -> bool:
+        return any(evt.is_step_skipped for evt in self.events_for_node(node_str))
+
+    def is_node_untouched(self, node_str: str) -> bool:
+        return len(self.events_for_node(node_str)) == 0
+
+    def get_run_failure_event(self) -> DagsterEvent:
+        """Returns a DagsterEvent with type DagsterEventType.RUN_FAILURE if it ocurred during
         execution.
         """
         events = self.filter_events(
@@ -134,8 +146,8 @@ class ExecutionResult(ABC):
 
         return events[0]
 
-    def get_job_success_event(self) -> DagsterEvent:
-        """Returns a DagsterEvent with type DagsterEventType.PIPELINE_SUCCESS if it ocurred during
+    def get_run_success_event(self) -> DagsterEvent:
+        """Returns a DagsterEvent with type DagsterEventType.RUN_SUCCESS if it ocurred during
         execution.
         """
         events = self.filter_events(
@@ -149,14 +161,14 @@ class ExecutionResult(ABC):
 
     def asset_materializations_for_node(self, node_name: str) -> Sequence[AssetMaterialization]:
         return [
-            cast(StepMaterializationData, event.event_specific_data).materialization
+            cast("StepMaterializationData", event.event_specific_data).materialization
             for event in self.events_for_node(node_name)
             if event.event_type_value == DagsterEventType.ASSET_MATERIALIZATION.value
         ]
 
     def asset_observations_for_node(self, node_name: str) -> Sequence[AssetObservation]:
         return [
-            cast(AssetObservationData, event.event_specific_data).asset_observation
+            cast("AssetObservationData", event.event_specific_data).asset_observation
             for event in self.events_for_node(node_name)
             if event.event_type_value == DagsterEventType.ASSET_OBSERVATION.value
         ]
@@ -164,17 +176,33 @@ class ExecutionResult(ABC):
     def get_asset_materialization_events(self) -> Sequence[DagsterEvent]:
         return [event for event in self.all_events if event.is_step_materialization]
 
+    def get_asset_materialization_planned_events(self) -> Sequence[DagsterEvent]:
+        return [event for event in self.all_events if event.is_asset_materialization_planned]
+
+    def get_asset_observation_events(self) -> Sequence[DagsterEvent]:
+        return [event for event in self.all_events if event.is_asset_observation]
+
+    def get_asset_check_evaluations(self) -> Sequence[AssetCheckEvaluation]:
+        return [
+            cast("AssetCheckEvaluation", event.event_specific_data)
+            for event in self.all_events
+            if event.event_type_value == DagsterEventType.ASSET_CHECK_EVALUATION.value
+        ]
+
     def get_step_success_events(self) -> Sequence[DagsterEvent]:
         return [event for event in self.all_events if event.is_step_success]
 
     def get_step_skipped_events(self) -> Sequence[DagsterEvent]:
         return [event for event in self.all_events if event.is_step_skipped]
 
+    def get_step_failure_events(self) -> Sequence[DagsterEvent]:
+        return [event for event in self.all_events if event.is_step_failure]
+
     def get_failed_step_keys(self) -> AbstractSet[str]:
         failure_events = self.filter_events(
             lambda event: event.is_step_failure or event.is_resource_init_failure
         )
-        keys: Set[str] = set()
+        keys: set[str] = set()
         for event in failure_events:
             if event.step_key:
                 keys.add(event.step_key)
@@ -197,7 +225,7 @@ class ExecutionResult(ABC):
             )
         )
         return [
-            cast(StepExpectationResultData, event.event_specific_data).expectation_result
+            cast("StepExpectationResultData", event.event_specific_data).expectation_result
             for event in expectation_result_events
         ]
 
