@@ -17,7 +17,8 @@ from dagster._core.execution.backfill import (
 from dagster._core.execution.plan.resume_retry import ReexecutionStrategy
 from dagster._core.execution.plan.state import KnownExecutionState
 from dagster._core.instance import DagsterInstance
-from dagster._core.remote_representation import CodeLocation, RemoteJob, RemotePartitionSet
+from dagster._core.remote_representation.code_location import CodeLocation
+from dagster._core.remote_representation.external import RemoteJob, RemotePartitionSet
 from dagster._core.remote_representation.external_data import PartitionSetExecutionParamSnap
 from dagster._core.storage.dagster_run import (
     NOT_FINISHED_STATUSES,
@@ -352,6 +353,7 @@ def submit_backfill_runs(
             job_name=partition_set.job_name,
             op_selection=None,
             asset_selection=backfill_job.asset_selection,
+            run_config=backfill_job.run_config,
         )
         remote_job = code_location.get_job(pipeline_selector)
     else:
@@ -377,7 +379,16 @@ def submit_backfill_runs(
     tags_by_key_or_range: Mapping[Union[str, PartitionKeyRange], Mapping[str, str]]
     run_config_by_key_or_range: Mapping[Union[str, PartitionKeyRange], Mapping[str, Any]]
     if isinstance(partition_names_or_ranges[0], PartitionKeyRange):
-        run_config = partition_set_execution_data.partition_data[0].run_config
+        partition_set_run_config = partition_set_execution_data.partition_data[0].run_config
+
+        if partition_set_run_config and backfill_job.run_config:
+            raise DagsterInvariantViolationError(
+                "Cannot specify both partition-scoped run config and backfill-scoped run config. This can happen "
+                "if you explicitly set a PartitionSet on your job and also specify run config when launching a backfill.",
+            )
+
+        run_config = partition_set_run_config or backfill_job.run_config or {}
+
         tags = {
             k: v
             for k, v in partition_set_execution_data.partition_data[0].tags.items()
@@ -394,7 +405,8 @@ def submit_backfill_runs(
         }
     else:
         run_config_by_key_or_range = {
-            pd.name: pd.run_config for pd in partition_set_execution_data.partition_data
+            pd.name: pd.run_config or backfill_job.run_config or {}
+            for pd in partition_set_execution_data.partition_data
         }
         tags_by_key_or_range = {
             pd.name: pd.tags for pd in partition_set_execution_data.partition_data
