@@ -19,10 +19,11 @@ def get_tag_concurrency_limits_config():
             )
         ),
         is_required=False,
-        description="A set of limits that are applied to steps with particular tags. "
-        "If a value is set, the limit is applied to only that key-value pair. "
-        "If no value is set, the limit is applied across all values of that key. "
-        "If the value is set to a dict with `applyLimitPerUniqueValue: true`, the limit "
-        "will apply to the number of unique values for that key. Note that these limits are per "
-        "run, not global.",
+        description=(
+            "A set of limits that are applied to steps with particular tags. If a value is set, the"
+            " limit is applied to only that key-value pair. If no value is set, the limit is"
+            " applied across all values of that key. If the value is set to a dict with"
+            " `applyLimitPerUniqueValue: true`, the limit will apply to the number of unique values"
+            " for that key. Note that these limits are per run, not global."
+        ),
     )
