@@ -46,6 +46,7 @@ if TYPE_CHECKING:
     from dagster._core.storage.compute_log_manager import ComputeLogManager
     from dagster._core.storage.daemon_cursor import DaemonCursorStorage
     from dagster._core.storage.dagster_run import JobBucket, RunRecord, TagBucket
+    from dagster._core.storage.defs_state.base import DefsStateStorage
     from dagster._core.storage.event_log import EventLogStorage
     from dagster._core.storage.event_log.base import (
         AssetRecord,
@@ -142,6 +143,7 @@ class DagsterInstance(
         schedule_storage: Optional["ScheduleStorage"] = None,
         settings: Optional[Mapping[str, Any]] = None,
         secrets_loader: Optional["SecretsLoader"] = None,
+        defs_state_storage: Optional["DefsStateStorage"] = None,
         ref: Optional[InstanceRef] = None,
         **_kwargs: Any,  # we accept kwargs for forward-compat of custom instances
     ):
@@ -150,6 +152,7 @@ class DagsterInstance(
         from dagster._core.scheduler import Scheduler
         from dagster._core.secrets import SecretsLoader
         from dagster._core.storage.compute_log_manager import ComputeLogManager
+        from dagster._core.storage.defs_state import DefsStateStorage
         from dagster._core.storage.event_log import EventLogStorage
         from dagster._core.storage.root import LocalArtifactStorage
         from dagster._core.storage.runs import RunStorage
@@ -210,6 +213,12 @@ class DagsterInstance(
         if self._secrets_loader:
             self._secrets_loader.register_instance(self)
 
+        self._defs_state_storage = check.opt_inst_param(
+            defs_state_storage, "defs_state_storage", DefsStateStorage
+        )
+        if self._defs_state_storage:
+            self._defs_state_storage.register_instance(self)
+
         self._ref = check.opt_inst_param(ref, "ref", InstanceRef)
 
         self._subscribers: dict[str, list[Callable]] = defaultdict(list)
@@ -753,6 +762,10 @@ class DagsterInstance(
     def run_storage(self) -> "RunStorage":
         return self._run_storage
 
+    @property
+    def defs_state_storage(self) -> Optional["DefsStateStorage"]:
+        return self._defs_state_storage
+
     @property
     def event_log_storage(self) -> "EventLogStorage":
         return self._event_storage
@@ -901,6 +914,9 @@ class DagsterInstance(
     # directories
 
     def __enter__(self) -> Self:
+        from dagster._core.storage.defs_state.base import DefsStateStorage
+
+        DefsStateStorage.set_current(self.defs_state_storage)
         return self
 
     def __exit__(
@@ -909,6 +925,9 @@ class DagsterInstance(
         _exception_value: Optional[BaseException],
         _traceback: Optional[TracebackType],
     ) -> None:
+        from dagster._core.storage.defs_state.base import DefsStateStorage
+
+        DefsStateStorage.set_current(None)
         self.dispose()
 
     # backfill
