@@ -1,27 +1,32 @@
 import time
-from typing import Any, Mapping, Optional, cast
+from collections.abc import Mapping
+from typing import TYPE_CHECKING, Any, Optional, cast
 
+import dagster_shared.seven as seven
 from typing_extensions import Self
 
-import dagster._seven as seven
-from dagster import (
-    _check as check,
-)
+from dagster import _check as check
+from dagster._annotations import public
 from dagster._config.config_schema import UserConfigSchema
-from dagster._core.errors import DagsterInvariantViolationError, DagsterLaunchFailedError
-from dagster._core.storage.pipeline_run import DagsterRun
-from dagster._core.storage.tags import GRPC_INFO_TAG
-from dagster._serdes import (
-    ConfigurableClass,
-    deserialize_value,
+from dagster._core.errors import (
+    DagsterInvariantViolationError,
+    DagsterLaunchFailedError,
+    DagsterUserCodeProcessError,
 )
+from dagster._core.launcher.base import LaunchRunContext, RunLauncher
+from dagster._core.storage.dagster_run import DagsterRun
+from dagster._core.storage.tags import GRPC_INFO_TAG
+from dagster._serdes import ConfigurableClass, deserialize_value
 from dagster._serdes.config_class import ConfigurableClassData
 from dagster._utils.merger import merge_dicts
 
-from .base import LaunchRunContext, RunLauncher
+if TYPE_CHECKING:
+    from dagster._core.instance import DagsterInstance
+    from dagster._grpc.client import DagsterGrpcClient
 
 
 # note: this class is a top level export, so we defer many imports til use for performance
+@public
 class DefaultRunLauncher(RunLauncher, ConfigurableClass):
     """Launches runs against running GRPC servers."""
 
@@ -47,12 +52,14 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
     def from_config_value(
         cls, inst_data: ConfigurableClassData, config_value: Mapping[str, Any]
     ) -> Self:
-        return DefaultRunLauncher(inst_data=inst_data)
+        return cls(inst_data=inst_data)
 
     @staticmethod
-    def launch_run_from_grpc_client(instance, run, grpc_client):
+    def launch_run_from_grpc_client(
+        instance: "DagsterInstance", run: DagsterRun, grpc_client: "DagsterGrpcClient"
+    ):
         # defer for perf
-        from dagster._grpc.types import ExecuteExternalPipelineArgs, StartRunResult
+        from dagster._grpc.types import ExecuteExternalJobArgs, StartRunResult
 
         instance.add_run_tags(
             run.run_id,
@@ -73,9 +80,9 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
 
         res = deserialize_value(
             grpc_client.start_run(
-                ExecuteExternalPipelineArgs(
-                    pipeline_origin=run.external_pipeline_origin,
-                    pipeline_run_id=run.run_id,
+                ExecuteExternalJobArgs(
+                    job_origin=run.remote_job_origin,  # type: ignore  # (possible none)
+                    run_id=run.run_id,
                     instance_ref=instance.get_ref(),
                 )
             ),
@@ -90,9 +97,7 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
 
     def launch_run(self, context: LaunchRunContext) -> None:
         # defer for perf
-        from dagster._core.host_representation.code_location import (
-            GrpcServerCodeLocation,
-        )
+        from dagster._core.remote_representation.code_location import GrpcServerCodeLocation
 
         run = context.dagster_run
 
@@ -103,9 +108,9 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
                 "DefaultRunLauncher requires a workspace to be included in its LaunchRunContext"
             )
 
-        external_pipeline_origin = check.not_none(run.external_pipeline_origin)
+        remote_job_origin = check.not_none(run.remote_job_origin)
         code_location = context.workspace.get_code_location(
-            external_pipeline_origin.external_repository_origin.code_location_origin.location_name
+            remote_job_origin.repository_origin.code_location_origin.location_name
         )
 
         check.inst(
@@ -115,7 +120,7 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
         )
 
         DefaultRunLauncher.launch_run_from_grpc_client(
-            self._instance, run, cast(GrpcServerCodeLocation, code_location).client
+            self._instance, run, cast("GrpcServerCodeLocation", code_location).client
         )
 
         self._run_ids.add(run.run_id)
@@ -136,7 +141,7 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
         if GRPC_INFO_TAG not in tags:
             return None
 
-        grpc_info = seven.json.loads(tags.get(GRPC_INFO_TAG))
+        grpc_info = seven.json.loads(tags.get(GRPC_INFO_TAG))  # pyright: ignore[reportArgumentType]
 
         return DagsterGrpcClient(
             port=grpc_info.get("port"),
@@ -154,23 +159,28 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
             return False
 
         run = self._instance.get_run_by_id(run_id)
-        if not run:
+        if not run or run.is_finished:
             return False
 
+        self._instance.report_run_canceling(run)
+
         client = self._get_grpc_client_for_termination(run_id)
 
         if not client:
             self._instance.report_engine_event(
                 message="Unable to get grpc client to send termination request to.",
-                pipeline_run=run,
+                dagster_run=run,
                 cls=self.__class__,
             )
             return False
 
-        self._instance.report_run_canceling(run)
         res = deserialize_value(
             client.cancel_execution(CancelExecutionRequest(run_id=run_id)), CancelExecutionResult
         )
+
+        if res.serializable_error_info:
+            raise DagsterUserCodeProcessError.from_error_info(res.serializable_error_info)
+
         return res.success
 
     def join(self, timeout=30):
@@ -187,7 +197,7 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
                 for run_id in self._run_ids
                 if (
                     self._instance.get_run_by_id(run_id)
-                    and not self._instance.get_run_by_id(run_id).is_finished
+                    and not self._instance.get_run_by_id(run_id).is_finished  # pyright: ignore[reportOptionalMemberAccess]
                 )
             ]
 
@@ -195,11 +205,7 @@ class DefaultRunLauncher(RunLauncher, ConfigurableClass):
                 return
 
             if total_time >= timeout:
-                raise Exception(
-                    "Timed out waiting for these runs to finish: {active_run_ids}".format(
-                        active_run_ids=repr(active_run_ids)
-                    )
-                )
+                raise Exception(f"Timed out waiting for these runs to finish: {active_run_ids!r}")
 
             total_time += interval
             time.sleep(interval)
