@@ -3,6 +3,7 @@ import threading
 from contextlib import AbstractContextManager
 from typing import TYPE_CHECKING, Any, NamedTuple, Optional, Union, cast
 
+from dagster_shared.serdes.objects import DefsStateInfo
 from typing_extensions import TypeGuard
 
 import dagster._check as check
@@ -75,6 +76,7 @@ class GrpcServerRegistry(AbstractContextManager):
         container_image: Optional[str] = None,
         container_context: Optional[dict[str, Any]] = None,
         additional_timeout_msg: Optional[str] = None,
+        defs_state_info: Optional[DefsStateInfo] = None,
     ):
         self.instance_ref = instance_ref
         self.server_command = server_command
@@ -89,6 +91,9 @@ class GrpcServerRegistry(AbstractContextManager):
         self._additional_timeout_msg = check.opt_str_param(
             additional_timeout_msg, "additional_timeout_msg"
         )
+        self._defs_state_info = check.opt_inst_param(
+            defs_state_info, "defs_state_info", DefsStateInfo
+        )
 
         self._lock = threading.Lock()
 
@@ -203,6 +208,7 @@ class GrpcServerRegistry(AbstractContextManager):
                     container_image=self._container_image,
                     container_context=self._container_context,
                     additional_timeout_msg=self._additional_timeout_msg,
+                    defs_state_info=self._defs_state_info,
                 )
                 self._all_processes.append(server_process)
                 self._active_entries[origin_id] = ServerRegistryEntry(
