@@ -1,3 +1,4 @@
+import contextlib
 import glob
 import logging
 import os
@@ -6,11 +7,16 @@ import sqlite3
 import threading
 import time
 from collections import defaultdict
+from collections.abc import Iterator, Sequence
 from contextlib import contextmanager
-from typing import TYPE_CHECKING, Any, ContextManager, Iterable, Iterator, Optional, Sequence
+from functools import cached_property
+from typing import TYPE_CHECKING, Any, ContextManager, Optional, Union  # noqa: UP035
 
+import dagster_shared.seven as seven
 import sqlalchemy as db
 import sqlalchemy.exc as db_exc
+from dagster_shared.serdes import deserialize_value
+from dagster_shared.serdes.errors import DeserializationError
 from sqlalchemy.engine import Connection, Engine
 from sqlalchemy.pool import NullPool
 from tqdm import tqdm
@@ -18,36 +24,43 @@ from watchdog.events import FileSystemEvent, PatternMatchingEventHandler
 from watchdog.observers import Observer
 
 import dagster._check as check
-import dagster._seven as seven
 from dagster._config import StringSource
 from dagster._config.config_schema import UserConfigSchema
 from dagster._core.definitions.events import AssetKey
 from dagster._core.errors import DagsterInvariantViolationError
-from dagster._core.event_api import EventHandlerFn
-from dagster._core.events import ASSET_EVENTS
+from dagster._core.event_api import EventHandlerFn, EventRecordsResult, RunStatusChangeRecordsFilter
+from dagster._core.events import (
+    ASSET_CHECK_EVENTS,
+    ASSET_EVENTS,
+    EVENT_TYPE_TO_PIPELINE_RUN_STATUS,
+    DagsterEventType,
+)
 from dagster._core.events.log import EventLogEntry
+from dagster._core.instance import RUNLESS_RUN_ID
+from dagster._core.storage.dagster_run import DagsterRunStatus, RunsFilter
 from dagster._core.storage.event_log.base import EventLogCursor, EventLogRecord, EventRecordsFilter
-from dagster._core.storage.pipeline_run import DagsterRunStatus, RunsFilter
+from dagster._core.storage.event_log.schema import (
+    SqlEventLogStorageMetadata,
+    SqlEventLogStorageTable,
+)
+from dagster._core.storage.event_log.sql_event_log import RunShardedEventsCursor, SqlEventLogStorage
 from dagster._core.storage.sql import (
     AlembicVersion,
     check_alembic_revision,
     create_engine,
     get_alembic_config,
     run_alembic_upgrade,
+    safe_commit,
     stamp_alembic_rev,
 )
-from dagster._core.storage.sqlite import create_db_conn_string
-from dagster._serdes import (
-    ConfigurableClass,
-    ConfigurableClassData,
+from dagster._core.storage.sqlalchemy_compat import db_select
+from dagster._core.storage.sqlite import (
+    LAST_KNOWN_STAMPED_SQLITE_ALEMBIC_REVISION,
+    create_db_conn_string,
 )
-from dagster._serdes.errors import DeserializationError
-from dagster._serdes.serdes import deserialize_value
+from dagster._serdes import ConfigurableClass, ConfigurableClassData
 from dagster._utils import mkdir_p
 
-from ..schema import SqlEventLogStorageMetadata, SqlEventLogStorageTable
-from ..sql_event_log import RunShardedEventsCursor, SqlEventLogStorage
-
 if TYPE_CHECKING:
     from dagster._core.storage.sqlite_storage import SqliteStorageConfig
 INDEX_SHARD_NAME = "index"
@@ -57,7 +70,7 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
     """SQLite-backed event log storage.
 
     Users should not directly instantiate this class; it is instantiated by internal machinery when
-    ``dagit`` and ``dagster-graphql`` load, based on the values in the ``dagster.yaml`` file in
+    ``dagster-webserver`` and ``dagster-graphql`` load, based on the values in the ``dagster.yaml`` file insqliteve
     ``$DAGSTER_HOME``. Configuration of this class should be done by setting values in that file.
 
     This is the default event log storage when none is specified in the ``dagster.yaml``.
@@ -100,7 +113,7 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
         if not os.path.exists(self.path_for_shard(INDEX_SHARD_NAME)):
             conn_string = self.conn_string_for_shard(INDEX_SHARD_NAME)
             engine = create_engine(conn_string, poolclass=NullPool)
-            self._initdb(engine)
+            self._initdb(engine, for_index_shard=True)
             self.reindex_events()
             self.reindex_assets()
 
@@ -130,7 +143,7 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
         return {"base_dir": StringSource}
 
     @classmethod
-    def from_config_value(
+    def from_config_value(  # pyright: ignore[reportIncompatibleMethodOverride]
         cls, inst_data: Optional[ConfigurableClassData], config_value: "SqliteStorageConfig"
     ) -> "SqliteEventLogStorage":
         return SqliteEventLogStorage(inst_data=inst_data, **config_value)
@@ -146,7 +159,8 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
     def has_table(self, table_name: str) -> bool:
         conn_string = self.conn_string_for_shard(INDEX_SHARD_NAME)
         engine = create_engine(conn_string, poolclass=NullPool)
-        return bool(engine.dialect.has_table(engine.connect(), table_name))
+        with engine.connect() as conn:
+            return bool(engine.dialect.has_table(conn, table_name))
 
     def path_for_shard(self, run_id: str) -> str:
         return os.path.join(self._base_dir, f"{run_id}.db")
@@ -155,7 +169,7 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
         check.str_param(shard_name, "shard_name")
         return create_db_conn_string(self._base_dir, shard_name)
 
-    def _initdb(self, engine: Engine) -> None:
+    def _initdb(self, engine: Engine, for_index_shard=False) -> None:
         alembic_config = get_alembic_config(__file__)
 
         retry_limit = 10
@@ -166,14 +180,24 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
                     db_revision, head_revision = check_alembic_revision(alembic_config, connection)
 
                     if not (db_revision and head_revision):
+                        table_names = db.inspect(engine).get_table_names()
+                        if "event_logs" in table_names and for_index_shard:
+                            # The event_log table exists but the alembic version table does not. This means that the SQLite db was
+                            # initialized with SQLAlchemy 2.0 before https://github.com/dagster-io/dagster/pull/25740 was merged.
+                            # We should pin the alembic revision to the last known stamped revision before we unpinned SQLAlchemy 2.0
+                            # This should be safe because we have guarded all known migrations since then.
+                            rev_to_stamp = LAST_KNOWN_STAMPED_SQLITE_ALEMBIC_REVISION
+                        else:
+                            rev_to_stamp = "head"
                         SqlEventLogStorageMetadata.create_all(engine)
-                        engine.execute("PRAGMA journal_mode=WAL;")
-                        stamp_alembic_rev(alembic_config, connection)
+                        connection.execute(db.text("PRAGMA journal_mode=WAL;"))
+                        stamp_alembic_rev(alembic_config, connection, rev=rev_to_stamp)
+                        safe_commit(connection)
 
                 break
             except (db_exc.DatabaseError, sqlite3.DatabaseError, sqlite3.OperationalError) as exc:
                 # This is SQLite-specific handling for concurrency issues that can arise when
-                # multiple processes (e.g. the dagit process and user code process) contend with
+                # multiple processes (e.g. the dagster-webserver process and user code process) contend with
                 # each other to init the db. When we hit the following errors, we know that another
                 # process is on the case and we should retry.
                 err_msg = str(exc)
@@ -189,10 +213,8 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
                     raise
                 else:
                     logging.info(
-                        (
-                            "SqliteEventLogStorage._initdb: Encountered apparent concurrent init, "
-                            "retrying (%s retries left). Exception: %s"
-                        ),
+                        "SqliteEventLogStorage._initdb: Encountered apparent concurrent init, "
+                        "retrying (%s retries left). Exception: %s",
                         retry_limit,
                         err_msg,
                     )
@@ -211,12 +233,9 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
                 self._initdb(engine)
                 self._initialized_dbs.add(shard)
 
-            conn = engine.connect()
-
-            try:
-                yield conn
-            finally:
-                conn.close()
+            with engine.connect() as conn:
+                with conn.begin():
+                    yield conn
             engine.dispose()
 
     def run_connection(self, run_id: Optional[str] = None) -> Any:
@@ -239,15 +258,7 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
         with self.run_connection(run_id) as conn:
             conn.execute(insert_event_statement)
 
-        if event.is_dagster_event and event.dagster_event.asset_key:  # type: ignore
-            check.invariant(
-                event.dagster_event_type in ASSET_EVENTS,
-                (
-                    "Can only store asset materializations, materialization_planned, and"
-                    " observations in index database"
-                ),
-            )
-
+        if event.is_dagster_event and event.dagster_event_type in ASSET_EVENTS:
             event_id = None
 
             # mirror the event in the cross-run index database
@@ -262,14 +273,22 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
                     "Cannot store asset event tags for null event id."
                 )
 
-            self.store_asset_event_tags(event, event_id)
+            self.store_asset_event_tags([event], [event_id])
+
+        if event.is_dagster_event and event.dagster_event_type in ASSET_CHECK_EVENTS:
+            self.store_asset_check_event(event, None)
+
+        if event.is_dagster_event and event.dagster_event_type in EVENT_TYPE_TO_PIPELINE_RUN_STATUS:
+            # should mirror run status change events in the index shard
+            with self.index_connection() as conn:
+                conn.execute(insert_event_statement)
 
     def get_event_records(
         self,
         event_records_filter: EventRecordsFilter,
         limit: Optional[int] = None,
         ascending: bool = False,
-    ) -> Iterable[EventLogRecord]:
+    ) -> Sequence[EventLogRecord]:
         """Overridden method to enable cross-run event queries in sqlite.
 
         The record id in sqlite does not auto increment cross runs, so instead of fetching events
@@ -283,11 +302,21 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
         if is_asset_query:
             # asset materializations, observations and materialization planned events
             # get mirrored into the index shard, so no custom run shard-aware cursor logic needed
-            return super(SqliteEventLogStorage, self).get_event_records(
+            return super().get_event_records(
                 event_records_filter=event_records_filter, limit=limit, ascending=ascending
             )
 
-        query = db.select([SqlEventLogStorageTable.c.id, SqlEventLogStorageTable.c.event])
+        return self._get_run_sharded_event_records(
+            event_records_filter=event_records_filter, limit=limit, ascending=ascending
+        )
+
+    def _get_run_sharded_event_records(
+        self,
+        event_records_filter: EventRecordsFilter,
+        limit: Optional[int] = None,
+        ascending: bool = False,
+    ) -> Sequence[EventLogRecord]:
+        query = db_select([SqlEventLogStorageTable.c.id, SqlEventLogStorageTable.c.event])
         if event_records_filter.asset_key:
             asset_details = next(iter(self._get_assets_details([event_records_filter.asset_key])))
         else:
@@ -331,20 +360,17 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
             ascending=ascending,
         )
 
-        event_records = []
-        for run_record in run_records:
-            run_id = run_record.dagster_run.run_id
+        def _get_event_records_for_run(run_id: str) -> Sequence[EventLogRecord]:
+            records = []
             with self.run_connection(run_id) as conn:
                 results = conn.execute(query).fetchall()
 
             for row_id, json_str in results:
                 try:
                     event_record = deserialize_value(json_str, EventLogEntry)
-                    event_records.append(
-                        EventLogRecord(storage_id=row_id, event_log_entry=event_record)
-                    )
-                    if limit and len(event_records) >= limit:
-                        break
+                    records.append(EventLogRecord(storage_id=row_id, event_log_entry=event_record))
+                    if limit and len(records) >= limit:
+                        return records
                 except DeserializationError:
                     logging.warning(
                         "Could not resolve event record as EventLogEntry for id `%s`.", row_id
@@ -352,32 +378,82 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
                 except seven.JSONDecodeError:
                     logging.warning("Could not parse event record id `%s`.", row_id)
 
+            return records
+
+        event_records = []
+        for run_record in run_records:
+            run_id = run_record.dagster_run.run_id
+            event_records.extend(_get_event_records_for_run(run_id))
+
             if limit and len(event_records) >= limit:
                 break
 
+        if not limit or len(event_records) < limit:
+            event_records.extend(_get_event_records_for_run(RUNLESS_RUN_ID))
+
         return event_records[:limit]
 
-    def supports_event_consumer_queries(self) -> bool:
-        return False
+    def fetch_run_status_changes(
+        self,
+        records_filter: Union[DagsterEventType, RunStatusChangeRecordsFilter],
+        limit: int,
+        cursor: Optional[str] = None,
+        ascending: bool = False,
+    ) -> EventRecordsResult:
+        # custom implementation of the run status change event query to only read from the index
+        # shard instead of from the run shards.  This bypasses the default Sqlite implementation of
+        # the deprecated _get_event_records method, which reads from the run shards, opting for the
+        # super implementation instead, which reads from the index shard
+        event_type = (
+            records_filter
+            if isinstance(records_filter, DagsterEventType)
+            else records_filter.event_type
+        )
+        if event_type not in EVENT_TYPE_TO_PIPELINE_RUN_STATUS:
+            expected = ", ".join(EVENT_TYPE_TO_PIPELINE_RUN_STATUS.keys())
+            check.failed(f"Expected one of {expected}, received {event_type.value}")
 
-    def delete_events(self, run_id: str) -> None:
-        with self.run_connection(run_id) as conn:
-            self.delete_events_for_run(conn, run_id)
+        before_cursor, after_cursor = EventRecordsFilter.get_cursor_params(cursor, ascending)
+        event_records_filter = (
+            records_filter.to_event_records_filter_without_job_names(cursor, ascending)
+            if isinstance(records_filter, RunStatusChangeRecordsFilter)
+            else EventRecordsFilter(
+                event_type, before_cursor=before_cursor, after_cursor=after_cursor
+            )
+        )
 
-        # delete the mirrored event in the cross-run index database
-        with self.index_connection() as conn:
-            self.delete_events_for_run(conn, run_id)
+        # bypass the run-sharded cursor logic... any caller of this run status change specific
+        # method should be reading from the index shard, which as of 1.5.0 contains mirrored run
+        # status change events
+        records = super().get_event_records(
+            event_records_filter=event_records_filter, limit=limit, ascending=ascending
+        )
+        if records:
+            new_cursor = EventLogCursor.from_storage_id(records[-1].storage_id).to_string()
+        elif cursor:
+            new_cursor = cursor
+        else:
+            new_cursor = EventLogCursor.from_storage_id(-1).to_string()
+        has_more = len(records) == limit
+        return EventRecordsResult(records, cursor=new_cursor, has_more=has_more)
 
     def wipe(self) -> None:
-        # should delete all the run-sharded dbs as well as the index db
+        # should delete all the run-sharded db files and drop the contents of the index
         for filename in (
             glob.glob(os.path.join(self._base_dir, "*.db"))
             + glob.glob(os.path.join(self._base_dir, "*.db-wal"))
             + glob.glob(os.path.join(self._base_dir, "*.db-shm"))
         ):
-            os.unlink(filename)
+            if (
+                not filename.endswith(f"{INDEX_SHARD_NAME}.db")
+                and not filename.endswith(f"{INDEX_SHARD_NAME}.db-wal")
+                and not filename.endswith(f"{INDEX_SHARD_NAME}.db-shm")
+            ):
+                with contextlib.suppress(FileNotFoundError):
+                    os.unlink(filename)
 
         self._initialized_dbs = set()
+        self._wipe_index()
 
     def _delete_mirrored_events_for_asset_key(self, asset_key: AssetKey) -> None:
         with self.index_connection() as conn:
@@ -391,7 +467,7 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
         # default implementation will update the event_logs in the sharded dbs, and the asset_key
         # table in the asset shard, but will not remove the mirrored event_log events in the asset
         # shard
-        super(SqliteEventLogStorage, self).wipe_asset(asset_key)
+        super().wipe_asset(asset_key)
         self._delete_mirrored_events_for_asset_key(asset_key)
 
     def watch(self, run_id: str, cursor: Optional[str], callback: EventHandlerFn) -> None:
@@ -402,7 +478,7 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
         watchdog = SqliteEventLogStorageWatchdog(self, run_id, callback, cursor)
         self._watchers[run_id][callback] = (
             watchdog,
-            self._obs.schedule(watchdog, self._base_dir, True),
+            self._obs.schedule(watchdog, self._base_dir, recursive=True),
         )
 
     def end_watch(self, run_id: str, handler: EventHandlerFn) -> None:
@@ -425,6 +501,10 @@ class SqliteEventLogStorage(SqlEventLogStorage, ConfigurableClass):
     def is_run_sharded(self) -> bool:
         return True
 
+    @cached_property
+    def supports_global_concurrency_limits(self) -> bool:
+        return self.has_table("concurrency_limits")
+
 
 class SqliteEventLogStorageWatchdog(PatternMatchingEventHandler):
     def __init__(
@@ -433,7 +513,7 @@ class SqliteEventLogStorageWatchdog(PatternMatchingEventHandler):
         run_id: str,
         callback: EventHandlerFn,
         cursor: Optional[str],
-        **kwargs: object,
+        **kwargs: Any,
     ):
         self._event_log_storage = check.inst_param(
             event_log_storage, "event_log_storage", SqliteEventLogStorage
@@ -442,7 +522,7 @@ class SqliteEventLogStorageWatchdog(PatternMatchingEventHandler):
         self._cb = check.callable_param(callback, "callback")
         self._log_path = event_log_storage.path_for_shard(run_id)
         self._cursor = cursor
-        super(SqliteEventLogStorageWatchdog, self).__init__(patterns=[self._log_path], **kwargs)
+        super().__init__(patterns=[self._log_path], **kwargs)
 
     def _process_log(self) -> None:
         connection = self._event_log_storage.get_records_for_run(self._run_id, self._cursor)
