@@ -2,10 +2,13 @@ import typing
 
 import dagster._check as check
 from dagster._config import Permissive
-from dagster._core.types.dagster_type import String
-
-from .config_schema import DagsterTypeLoader, dagster_type_loader
-from .dagster_type import DagsterType, PythonObjectDagsterType, resolve_dagster_type
+from dagster._core.types.config_schema import DagsterTypeLoader, dagster_type_loader
+from dagster._core.types.dagster_type import (
+    DagsterType,
+    PythonObjectDagsterType,
+    String,
+    resolve_dagster_type,
+)
 
 
 @dagster_type_loader(Permissive())
@@ -23,16 +26,21 @@ PythonDict = PythonObjectDagsterType(
 
 class TypedDictLoader(DagsterTypeLoader):
     def __init__(self, key_dagster_type, value_dagster_type):
-        from ..._config import ConfigTypeKind, Map, ScalarUnion
+        from dagster._config import ConfigTypeKind, Map, ScalarUnion
 
-        self._key_dagster_type = check.inst_param(key_dagster_type, "key_dagster_type", DagsterType)
+        self._key_dagster_type = check.inst_param(
+            key_dagster_type, "key_dagster_type", DagsterType
+        )
         check.param_invariant(self._key_dagster_type.loader, "key_dagster_type")
 
         # Scalar union config types allow for passing scalar values either directly,
         # or as a dictionary mapping set keys to a value. When a scalar union config type
         # is used as the key type for a dictionary, we extract the scalar type
         # only, so that we only permit passing the scalar value directly.
-        if self._key_dagster_type.loader.schema_type.kind == ConfigTypeKind.SCALAR_UNION:
+        if (
+            self._key_dagster_type.loader.schema_type.kind
+            == ConfigTypeKind.SCALAR_UNION
+        ):
             key_schema_type = typing.cast(
                 ScalarUnion, self._key_dagster_type.loader.schema_type
             ).scalar_type
@@ -56,8 +64,10 @@ class TypedDictLoader(DagsterTypeLoader):
         config_value = check.dict_param(config_value, "config_value")
         runtime_value = dict()
         for key, val in config_value.items():
-            runtime_value[key] = self._value_dagster_type.loader.construct_from_config_value(
-                context, val
+            runtime_value[key] = (
+                self._value_dagster_type.loader.construct_from_config_value(
+                    context, val
+                )
             )
         return runtime_value
 
@@ -66,15 +76,18 @@ class _TypedPythonDict(DagsterType):
     def __init__(self, key_type, value_type):
         self.key_type = check.inst_param(key_type, "key_type", DagsterType)
         self.value_type = check.inst_param(value_type, "value_type", DagsterType)
-        can_get_from_config = self.value_type.loader is not None and isinstance(
-            self.key_type, type(String)
+        can_get_from_config = (
+            self.value_type.loader is not None
+            and isinstance(self.key_type, type(String))
         )  # True if value_type has a DagsterTypeLoader, meaning we can load the input from config,
         # otherwise False.
         super(_TypedPythonDict, self).__init__(
             key=f"TypedPythonDict.{key_type.key}.{value_type.key}",
             name=None,
             loader=(
-                TypedDictLoader(self.key_type, self.value_type) if can_get_from_config else None
+                TypedDictLoader(self.key_type, self.value_type)
+                if can_get_from_config
+                else None
             ),
             type_check_fn=self.type_check_method,
             typing_type=typing.Dict[key_type.typing_type, value_type.typing_type],
@@ -86,9 +99,7 @@ class _TypedPythonDict(DagsterType):
         if not isinstance(value, dict):
             return TypeCheck(
                 success=False,
-                description="Value should be a dict, got a {value_type}".format(
-                    value_type=type(value)
-                ),
+                description=f"Value should be a dict, got a {type(value)}",
             )
 
         for key, value in value.items():
@@ -103,9 +114,7 @@ class _TypedPythonDict(DagsterType):
 
     @property
     def display_name(self):
-        return "Dict[{key},{value}]".format(
-            key=self.key_type.display_name, value=self.value_type.display_name
-        )
+        return f"Dict[{self.key_type.display_name},{self.value_type.display_name}]"
 
     @property
     def inner_types(self):
