@@ -1,19 +1,23 @@
-from .config_class import (
-    ConfigurableClass as ConfigurableClass,
-    ConfigurableClassData as ConfigurableClassData,
-    class_from_code_pointer as class_from_code_pointer,
-)
-from .serdes import (
+from dagster_shared.serdes.serdes import (
     EnumSerializer as EnumSerializer,
     NamedTupleSerializer as NamedTupleSerializer,
+    SerializableNonScalarKeyMapping as SerializableNonScalarKeyMapping,
     WhitelistMap as WhitelistMap,
     deserialize_value as deserialize_value,
+    deserialize_values as deserialize_values,
+    get_storage_name as get_storage_name,
     pack_value as pack_value,
     serialize_value as serialize_value,
     unpack_value as unpack_value,
     whitelist_for_serdes as whitelist_for_serdes,
 )
-from .utils import (
+from dagster_shared.serdes.utils import (
     create_snapshot_id as create_snapshot_id,
     serialize_pp as serialize_pp,
 )
+
+from dagster._serdes.config_class import (
+    ConfigurableClass as ConfigurableClass,
+    ConfigurableClassData as ConfigurableClassData,
+    class_from_code_pointer as class_from_code_pointer,
+)
